SystemCommand

Enum SystemCommand 

pub enum SystemCommand {
Show 32 variants ActivateApp(ApplicationId), CloseApp(ApplicationId), LoadDataSource(LogDataSource), AddReceiver(LogReceiver), AddRedapServer(Origin), EditRedapServerModal(EditRedapServerModalCommand), OpenSettings, OpenChunkStoreBrowser { store_id: Option<StoreId>, selected_chunk: Option<ChunkId>, }, SetRoute(Route), ResetRoute, ResetViewer, ClearActiveBlueprint, ClearActiveBlueprintAndEnableHeuristics, CloseRecordingOrTable(RecordingOrTable), CloseAllEntries, AppendToStore(StoreId, Vec<Chunk>), UndoBlueprint { blueprint_id: StoreId, }, RedoBlueprint { blueprint_id: StoreId, }, DropEntity(StoreId, EntityPath), EnableInspectBlueprintTimeline(bool), SetUrlFragment { store_id: StoreId, fragment: Fragment, }, CopyViewerUrl(String), SetSelection(SetSelection), TimeControlCommands { store_id: StoreId, time_commands: Vec<TimeControlCommand>, }, SetFocus(Item), ShowNotification(Notification), ReadbackAndSaveTexture(TextureReadbackId), FileSaver(Box<dyn FnOnce() -> Result<PathBuf, Error> + Send>), OnAuthChanged(Option<AuthContext>), SetAuthCredentials { access_token: String, email: String, }, Logout, SaveScreenshot { target: ScreenshotTarget, view_id: Option<BlueprintId<ViewIdRegistry>>, },
}
Commands used by internal system components

Variants



ActivateApp(ApplicationId)

Make this the active application.



CloseApp(ApplicationId)

Close this app and all its recordings.



LoadDataSource(LogDataSource)

Load data from a given data source.

Will not load any new data if the source is already one of the active data sources.



AddReceiver(LogReceiver)

Add a new receiver for log messages.



AddRedapServer(Origin)

Add a new server to the redap browser.



EditRedapServerModal(EditRedapServerModalCommand)

Open a modal to edit this redap server.



OpenSettings

Activates the setting route.



OpenChunkStoreBrowser

Activates the chunk store route.

Fields

store_id: Option<StoreId>
selected_chunk: Option<ChunkId>


SetRoute(Route)



ResetRoute

Sets the route to what it is at startup.



ResetViewer

Reset the Viewer to the default state



ClearActiveBlueprint

Clear the active blueprint.

This may have two outcomes:

  • If a default blueprint is set, it will be used.
  • Otherwise, the heuristics will be enabled.

To force using the heuristics, use Self::ClearActiveBlueprintAndEnableHeuristics.

UI note: because of the above ambiguity, controls for this command should only be enabled if a default blueprint is set or the behavior is explicitly explained.



ClearActiveBlueprintAndEnableHeuristics

Clear the active blueprint and enable heuristics.

The final outcome of this is to set the active blueprint to the heuristics. This command does not affect the default blueprint if any was set.



CloseRecordingOrTable(RecordingOrTable)

Close an RecordingOrTable and free its memory.



CloseAllEntries

Close all stores and show the welcome screen again.



AppendToStore(StoreId, Vec<Chunk>)

Add more data to a store (blueprint or recording).

Edit recordings with case: we generally regard recordings as immutable.

For blueprints,the StoreId should generally be the currently selected blueprint.

Instead of using this directly, consider using save_blueprint_archetype or similar.



UndoBlueprint

Fields

blueprint_id: StoreId


RedoBlueprint

Fields

blueprint_id: StoreId


DropEntity(StoreId, EntityPath)

Drop a specific entity from a store.

Also drops all recursive children.

The StoreId should generally be the currently selected blueprint but is tracked manually to ensure self-consistency if the blueprint is both modified and changed in the same frame.



EnableInspectBlueprintTimeline(bool)

Show a timeline of the blueprint data.



SetUrlFragment

Navigate to time/entities/anchors/etc. that are set in a re_uri::Fragment.

Fields

store_id: StoreId
fragment: Fragment


CopyViewerUrl(String)

Copies the given url to the clipboard.

On web this adds the viewer url as the base url.



SetSelection(SetSelection)

Set the item selection.



TimeControlCommands

Fields

store_id: StoreId
time_commands: Vec<TimeControlCommand>


SetFocus(Item)

Sets the focus to the given item.

The focused item is cleared out every frame. Focusing is triggered either explicitly by ui-elements saying so or by double-clicking on a button representing an item.

Unlike item selection, item focusing is not global state. It may however have stateful effects in certain views, e.g. the 3D view may follow the last focused item as it moves, or a frame may be highlighted for a few frames.

Just like selection highlighting, the exact behavior of focusing is up to the receiving views.



ShowNotification(Notification)

Show a notification to the user



ReadbackAndSaveTexture(TextureReadbackId)

Start polling a texture we’re reading back from the gpu, and then prompt the user to save a png of the texture.



FileSaver(Box<dyn FnOnce() -> Result<PathBuf, Error> + Send>)

Add a task, run on a background thread, that saves something to disk.



OnAuthChanged(Option<AuthContext>)

Notify about authentication changes.



SetAuthCredentials

Set authentication credentials from an external source.

Fields

access_token: String
email: String


Logout

Logout from rerun cloud



SaveScreenshot

Save a screenshot to a file.

Fields

target: ScreenshotTarget

Where to save the screenshot.

view_id: Option<BlueprintId<ViewIdRegistry>>

Optional view id to screenshot a specific view. If None, screenshots the entire viewer.

Implementations

Source

impl SystemCommand

pub fn clear_selection() -> SystemCommand

pub fn set_selection(selection: impl Into<SetSelection>) -> SystemCommand

Source

impl SystemCommand

pub fn debug_name(&self) -> &'static str

A short debug name for this command.